#include <boost/math/special_functions/expint.hpp>
#include "../boostmath/macros.hpp"

BINARY_BOOST_FUNCTION_SUFFIX(expint, en_, uint64_t, double);
UNARY_BOOST_FUNCTION_SUFFIX(expint, ei_, double);
